@@ -17,14 +17,14 @@ describe 'watcher::keystone::authtoken' do
       it 'configure keystone_authtoken' do
         is_expected.to contain_watcher_config('keystone_authtoken/username').with_value('watcher')
         is_expected.to contain_watcher_config('keystone_authtoken/password').with_value('watcher_password')
-        is_expected.to contain_watcher_config('keystone_authtoken/auth_url').with_value('http://localhost:35357')
+        is_expected.to contain_watcher_config('keystone_authtoken/auth_url').with_value('http://localhost:5000')
         is_expected.to contain_watcher_config('keystone_authtoken/project_name').with_value('services')
         is_expected.to contain_watcher_config('keystone_authtoken/user_domain_name').with_value('Default')
         is_expected.to contain_watcher_config('keystone_authtoken/project_domain_name').with_value('Default')
         is_expected.to contain_watcher_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/auth_type').with_value('password')
-        is_expected.to contain_watcher_config('keystone_authtoken/auth_uri').with_value('http://localhost:5000')
+        is_expected.to contain_watcher_config('keystone_authtoken/www_authenticate_uri').with_value('http://localhost:5000')
         is_expected.to contain_watcher_config('keystone_authtoken/auth_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
@@ -54,10 +54,10 @@ describe 'watcher::keystone::authtoken' do
     context 'when overriding parameters' do
       before do
         params.merge!({
-          :auth_uri                             => 'https://10.0.0.1:9999/',
+          :www_authenticate_uri                 => 'https://10.0.0.1:9999/',
           :username                             => 'myuser',
           :password                             => 'mypasswd',
-          :auth_url                             => 'http://:127.0.0.1:35357',
+          :auth_url                             => 'http://:127.0.0.1:5000',
           :project_name                         => 'service_project',
           :user_domain_name                     => 'domainX',
           :project_domain_name                  => 'domainX',
@@ -92,7 +92,7 @@ describe 'watcher::keystone::authtoken' do
       end
 
       it 'configure keystone_authtoken' do
-        is_expected.to contain_watcher_config('keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
+        is_expected.to contain_watcher_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_watcher_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_watcher_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_watcher_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
